@@ -1,12 +1,13 @@
 /*
  *  WINGs server.c: example how to create a network server using WMConnection
  *
- *  Copyright (c) 2001-2002 Dan Pascu
+ *  Copyright (c) 2001-2003 Dan Pascu
  *
  */
 
 
 #include <stdio.h>
+#include <stdlib.h>
 #include <unistd.h>
 #include <string.h>
 
@@ -42,6 +43,7 @@ static WMConnection *serverPtr = NULL;
 
 static ConnectionDelegate socketDelegate = {
     NULL,                 /* client data */
+    NULL,                 /* canResumeSending */
     NULL,                 /* didCatchException */
     connectionDidDie,     /* didDie */
     NULL,                 /* didInitialize */
