@@ -19,11 +19,13 @@
 #endif
 
 
-#if (!defined (__GNUC__) || __GNUC__ < 2 || \
-     __GNUC_MINOR__ < (defined (__cplusplus) ? 6 : 4))
-#define __ASSERT_FUNCTION       ((char *) 0)
-#else
-#define __ASSERT_FUNCTION       __PRETTY_FUNCTION__
+#ifndef __ASSERT_FUNCTION
+# if (!defined (__GNUC__) || (__GNUC__ < 2 && \
+      __GNUC_MINOR__ < (defined (__cplusplus) ? 6 : 4)))
+#  define __ASSERT_FUNCTION       ((char *) 0)
+# else
+#  define __ASSERT_FUNCTION       __PRETTY_FUNCTION__
+# endif
 #endif
 
 
@@ -45,18 +47,18 @@
 #else /* !DEBUG */
 
 #define wassertr(expr) \
-	if (!(expr)) { \
-		wwarning("%s line %i (%s): assertion %s failed",\
-			__FILE__, __LINE__, __ASSERT_FUNCTION, #expr);\
-		return;\
-	}
+    if (!(expr)) { \
+        wwarning("%s line %i (%s): assertion %s failed",\
+                 __FILE__, __LINE__, __ASSERT_FUNCTION, #expr);\
+        return;\
+    }
 
 #define wassertrv(expr, val) \
-	if (!(expr)) { \
-		wwarning("%s line %i (%s): assertion %s failed",\
-			__FILE__, __LINE__, __ASSERT_FUNCTION, #expr);\
-		return (val);\
-	}
+    if (!(expr)) { \
+        wwarning("%s line %i (%s): assertion %s failed",\
+                 __FILE__, __LINE__, __ASSERT_FUNCTION, #expr);\
+        return (val);\
+    }
 #endif /* !DEBUG */
 
 #endif /* !NDEBUG */
@@ -69,15 +71,15 @@ extern "C" {
 
 typedef enum {
     WMPostWhenIdle = 1,
-	WMPostASAP = 2,
-	WMPostNow = 3
+    WMPostASAP = 2,
+    WMPostNow = 3
 } WMPostingStyle;
 
 
 typedef enum {
     WNCNone = 0,
-	WNCOnName = 1,
-	WNCOnSender = 2
+    WNCOnName = 1,
+    WNCOnSender = 2
 } WMNotificationCoalescing;
 
 
@@ -164,7 +166,7 @@ typedef struct {
     /* NULL does nothing */
     void*	(*retainKey)(const void *);
     /* NULL does nothing */
-    void	(*releaseKey)(const void *);    
+    void	(*releaseKey)(const void *);
 } WMHashTableCallbacks;
 
 
@@ -184,8 +186,9 @@ typedef struct {
 typedef struct ConnectionDelegate {
     void *data;
 
-    void (*didCatchException)(struct ConnectionDelegate *self,
-                              WMConnection *cPtr);
+    void (*canResumeSending)(struct ConnectionDelegate *self, WMConnection *cPtr);
+
+    void (*didCatchException)(struct ConnectionDelegate *self, WMConnection *cPtr);
 
     void (*didDie)(struct ConnectionDelegate *self, WMConnection *cPtr);
 
@@ -198,8 +201,8 @@ typedef struct ConnectionDelegate {
 } ConnectionDelegate;
 
 
-typedef void WMNotificationObserverAction(void *observerData, 
-					  WMNotification *notification);
+typedef void WMNotificationObserverAction(void *observerData,
+                                          WMNotification *notification);
 
 
 
@@ -231,14 +234,18 @@ char* wexpandpath(char *path);
 char* wgethomedir();
 
 void* wmalloc(size_t size);
+void* wmalloc0(size_t size);
 void* wrealloc(void *ptr, size_t newsize);
 void wfree(void *ptr);
 
+#define wnew(type, count) wmalloc(sizeof(type)*count)
+#define wnew0(type, count) wmalloc0(sizeof(type)*count)
 
 void wrelease(void *ptr);
 void* wretain(void *ptr);
 
 char* wstrdup(char *str);
+char* wstrndup(char *str, size_t len);
 
 /* Concatenate str1 with str2 and return that in a newly malloc'ed string.
  * str1 and str2 can be any strings including static and constant strings.
@@ -281,7 +288,7 @@ void wusleep(unsigned int microsec);
 
 #if 0
 int wsprintesc(char *buffer, int length, char *format, WMSEscapes **escapes,
-	       int count);
+               int count);
 #endif
 
 /*......................................................................*/
@@ -289,7 +296,7 @@ int wsprintesc(char *buffer, int length, char *format, WMSEscapes **escapes,
 /* Event handlers: timer, idle, input */
 
 WMHandlerID WMAddTimerHandler(int milliseconds, WMCallback *callback,
-			      void *cdata);
+                              void *cdata);
 
 WMHandlerID WMAddPersistentTimerHandler(int milliseconds, WMCallback *callback,
                                         void *cdata);
@@ -302,8 +309,8 @@ WMHandlerID WMAddIdleHandler(WMCallback *callback, void *cdata);
 
 void WMDeleteIdleHandler(WMHandlerID handlerID);
 
-WMHandlerID WMAddInputHandler(int fd, int condition, WMInputProc *proc, 
-			      void *clientData);
+WMHandlerID WMAddInputHandler(int fd, int condition, WMInputProc *proc,
+                              void *clientData);
 
 void WMDeleteInputHandler(WMHandlerID handlerID);
 
@@ -369,7 +376,7 @@ extern const WMHashTableCallbacks WMIntHashCallbacks;
 /* sizeof(keys) are <= sizeof(void*) */
 
 extern const WMHashTableCallbacks WMStringHashCallbacks;
-/* keys are strings. Strings will be copied with wstrdup() 
+/* keys are strings. Strings will be copied with wstrdup()
  * and freed with wfree() */
 
 extern const WMHashTableCallbacks WMStringPointerHashCallbacks;
@@ -388,7 +395,7 @@ extern const WMHashTableCallbacks WMStringPointerHashCallbacks;
  * Fast [O(1)] push/pop
  *
  * Cons:
- * A little slower [O(n)] for insertion/deletion of elements that 
+ * A little slower [O(n)] for insertion/deletion of elements that
  * 	aren't in the end
  */
 
@@ -471,23 +478,23 @@ void* WMArrayPrevious(WMArray *array, WMArrayIterator *iter);
 
 /* The following 2 macros assume that the array doesn't change in the for loop */
 #define WM_ITERATE_ARRAY(array, var, i) \
-      	for (var = WMArrayFirst(array, &(i)); (i) != WANotFound; \
-		var = WMArrayNext(array, &(i)))
+    for (var = WMArrayFirst(array, &(i)); (i) != WANotFound; \
+    var = WMArrayNext(array, &(i)))
 
 #define WM_ETARETI_ARRAY(array, var, i) \
-      	for (var = WMArrayLast(array, &(i)); (i) != WANotFound; \
-		var = WMArrayPrevious(array, &(i)))
+    for (var = WMArrayLast(array, &(i)); (i) != WANotFound; \
+    var = WMArrayPrevious(array, &(i)))
 
 /*..........................................................................*/
 
 /*
  * Tree bags use a red-black tree for storage.
  * Item indexes may be any integer number.
- * 
+ *
  * Pros:
  * O(lg n) insertion/deletion/search
  * Good for large numbers of elements with sparse indexes
- * 
+ *
  * Cons:
  * O(lg n) insertion/deletion/search
  * Slow for storing small numbers of elements
@@ -561,12 +568,12 @@ int WMBagIndexForIterator(WMBag *bag, WMBagIterator ptr);
 
 /* The following 2 macros assume that the bag doesn't change in the for loop */
 #define WM_ITERATE_BAG(bag, var, i) \
-      	for (var = WMBagFirst(bag, &(i)); (i) != NULL; \
-		var = WMBagNext(bag, &(i)))
+    for (var = WMBagFirst(bag, &(i)); (i) != NULL; \
+    var = WMBagNext(bag, &(i)))
 
 #define WM_ETARETI_BAG(bag, var, i) \
-      	for (var = WMBagLast(bag, &(i)); (i) != NULL; \
-		var = WMBagPrevious(bag, &(i)))
+    for (var = WMBagLast(bag, &(i)); (i) != NULL; \
+    var = WMBagPrevious(bag, &(i)))
 
 
 
@@ -699,15 +706,15 @@ void* WMGetNotificationObject(WMNotification *notification);
 const char* WMGetNotificationName(WMNotification *notification);
 
 
-void WMAddNotificationObserver(WMNotificationObserverAction *observerAction, 
-			       void *observer, const char *name, void *object);
+void WMAddNotificationObserver(WMNotificationObserverAction *observerAction,
+                               void *observer, const char *name, void *object);
 
 void WMPostNotification(WMNotification *notification);
 
 void WMRemoveNotificationObserver(void *observer);
 
-void WMRemoveNotificationObserverWithName(void *observer, const char *name, 
-					  void *object);
+void WMRemoveNotificationObserverWithName(void *observer, const char *name,
+                                          void *object);
 
 void WMPostNotificationName(const char *name, void *object, void *clientData);
 
@@ -715,18 +722,18 @@ WMNotificationQueue* WMGetDefaultNotificationQueue(void);
 
 WMNotificationQueue* WMCreateNotificationQueue(void);
 
-void WMDequeueNotificationMatching(WMNotificationQueue *queue, 
-				   WMNotification *notification, 
-				   unsigned mask);
+void WMDequeueNotificationMatching(WMNotificationQueue *queue,
+                                   WMNotification *notification,
+                                   unsigned mask);
 
 void WMEnqueueNotification(WMNotificationQueue *queue,
-			   WMNotification *notification,
-			   WMPostingStyle postingStyle);
+                           WMNotification *notification,
+                           WMPostingStyle postingStyle);
 
-void WMEnqueueCoalesceNotification(WMNotificationQueue *queue, 
-				   WMNotification *notification,
-				   WMPostingStyle postingStyle,
-				   unsigned coalesceMask);
+void WMEnqueueCoalesceNotification(WMNotificationQueue *queue,
+                                   WMNotification *notification,
+                                   WMPostingStyle postingStyle,
+                                   unsigned coalesceMask);
 
 
 /*......................................................................*/
@@ -851,7 +858,7 @@ WMPropList* WMGetUDKeys(WMUserDefaults *database);
 WMPropList* WMGetUDObjectForKey(WMUserDefaults *database, char *defaultName);
 
 void WMSetUDObjectForKey(WMUserDefaults *database, WMPropList *object,
-			 char *defaultName);
+                         char *defaultName);
 
 void WMRemoveUDObjectForKey(WMUserDefaults *database, char *defaultName);
 
@@ -863,17 +870,17 @@ float WMGetUDFloatForKey(WMUserDefaults *database, char *defaultName);
 
 Bool WMGetUDBoolForKey(WMUserDefaults *database, char *defaultName);
 
-void WMSetUDStringForKey(WMUserDefaults *database, char *value, 
-			 char *defaultName);
+void WMSetUDStringForKey(WMUserDefaults *database, char *value,
+                         char *defaultName);
 
-void WMSetUDIntegerForKey(WMUserDefaults *database, int value, 
-			  char *defaultName);
+void WMSetUDIntegerForKey(WMUserDefaults *database, int value,
+                          char *defaultName);
 
-void WMSetUDFloatForKey(WMUserDefaults *database, float value, 
-			char *defaultName);
+void WMSetUDFloatForKey(WMUserDefaults *database, float value,
+                        char *defaultName);
 
 void WMSetUDBoolForKey(WMUserDefaults *database, Bool value,
-		       char *defaultName);
+                       char *defaultName);
 
 WMPropList* WMGetUDSearchList(WMUserDefaults *database);
 
@@ -977,6 +984,8 @@ Bool WMSetConnectionNonBlocking(WMConnection *cPtr, Bool flag);
 
 Bool WMSetConnectionCloseOnExec(WMConnection *cPtr, Bool flag);
 
+void WMSetConnectionShutdownOnClose(WMConnection *cPtr, Bool flag);
+
 void* WMGetConnectionClientData(WMConnection *cPtr);
 
 void WMSetConnectionClientData(WMConnection *cPtr, void *data);
