@@ -1,6 +1,7 @@
 
 
 #include "WINGsP.h"
+#include "wconfig.h"
 
 #include <X11/Xlocale.h>
 
@@ -9,9 +10,9 @@ _WINGsConfiguration WINGsConfiguration;
 
 
 
-#define SYSTEM_FONT "-*-helvetica-medium-r-normal-*-%d-*-*-*-*-*-*-*,-*-*-medium-r-*-*-%d-*-*-*-*-*-*-*"
-
-#define BOLD_SYSTEM_FONT "-*-helvetica-bold-r-normal-*-%d-*-*-*-*-*-*-*,-*-*-bold-r-*-*-%d-*-*-*-*-*-*-*"
+#define SYSTEM_FONT "Trebuchet MS,Luxi Sans"
+#define BOLD_SYSTEM_FONT "Trebuchet MS,Luxi Sans:bold"
+#define DEFAULT_FONT_SIZE 12
 
 #define FLOPPY_PATH "/floppy"
 
@@ -52,40 +53,21 @@ W_ReadConfigurations(void)
     if (defaults) {
         char *buttonName;
         unsigned button;
-	char *str;
 
-	WINGsConfiguration.systemFont = 
-	    WMGetUDStringForKey(defaults, "SystemFont");
+        WINGsConfiguration.systemFont =
+            WMGetUDStringForKey(defaults, "SystemFont");
 
-	WINGsConfiguration.boldSystemFont = 
-	    WMGetUDStringForKey(defaults, "BoldSystemFont");
+        WINGsConfiguration.boldSystemFont =
+            WMGetUDStringForKey(defaults, "BoldSystemFont");
 
-	WINGsConfiguration.useMultiByte = False;
-	str = WMGetUDStringForKey(defaults, "MultiByteText");
-	if (str) {
-	    if (strcasecmp(str, "YES") == 0) {
-		WINGsConfiguration.useMultiByte = True;
-	    } else if (strcasecmp(str, "AUTO") == 0) {
-		char *locale;
-		
-		/* if it's a multibyte language (japanese, chinese or korean)
-		 * then set it to True */
-		locale = setlocale(LC_CTYPE, NULL);
-		if (locale != NULL 
-		    && (strncmp(locale, "ja", 2) == 0
-			|| strncmp(locale, "zh", 2) == 0
-			|| strncmp(locale, "ko", 2) == 0)) {
+        WINGsConfiguration.antialiasedText =
+            WMGetUDBoolForKey(defaults, "AntialiasedText");
 
-		    WINGsConfiguration.useMultiByte = True;
-		}
-	    }
-	}
+        WINGsConfiguration.doubleClickDelay =
+            WMGetUDIntegerForKey(defaults, "DoubleClickTime");
 
-	WINGsConfiguration.doubleClickDelay = 
-	    WMGetUDIntegerForKey(defaults, "DoubleClickTime");	
-
-	WINGsConfiguration.floppyPath =
-	    WMGetUDStringForKey(defaults, "FloppyPath");
+        WINGsConfiguration.floppyPath =
+            WMGetUDStringForKey(defaults, "FloppyPath");
 
         buttonName = WMGetUDStringForKey(defaults, "MouseWheelUp");
         if (buttonName) {
@@ -110,31 +92,30 @@ W_ReadConfigurations(void)
             WINGsConfiguration.mouseWheelDown = Button5;
         }
 
-	WINGsConfiguration.defaultFontSize = 
+        WINGsConfiguration.defaultFontSize =
             WMGetUDIntegerForKey(defaults, "DefaultFontSize");
     }
 
-
     if (!WINGsConfiguration.systemFont) {
-	WINGsConfiguration.systemFont = SYSTEM_FONT;
+        WINGsConfiguration.systemFont = SYSTEM_FONT;
     }
     if (!WINGsConfiguration.boldSystemFont) {
-	WINGsConfiguration.boldSystemFont = BOLD_SYSTEM_FONT;
-    }
-    if (!WINGsConfiguration.floppyPath) {
-	WINGsConfiguration.floppyPath = FLOPPY_PATH;
-    }
-    if (WINGsConfiguration.doubleClickDelay == 0) {
-	WINGsConfiguration.doubleClickDelay = 250;
-    }
-    if (WINGsConfiguration.mouseWheelUp == 0) {
-	WINGsConfiguration.mouseWheelUp = Button4;
-    }
-    if (WINGsConfiguration.mouseWheelDown == 0) {
-	WINGsConfiguration.mouseWheelDown = Button5;
+        WINGsConfiguration.boldSystemFont = BOLD_SYSTEM_FONT;
     }
     if (WINGsConfiguration.defaultFontSize == 0) {
-	WINGsConfiguration.defaultFontSize = 12;
+        WINGsConfiguration.defaultFontSize = DEFAULT_FONT_SIZE;
+    }
+    if (!WINGsConfiguration.floppyPath) {
+        WINGsConfiguration.floppyPath = FLOPPY_PATH;
+    }
+    if (WINGsConfiguration.doubleClickDelay == 0) {
+        WINGsConfiguration.doubleClickDelay = 250;
+    }
+    if (WINGsConfiguration.mouseWheelUp == 0) {
+        WINGsConfiguration.mouseWheelUp = Button4;
+    }
+    if (WINGsConfiguration.mouseWheelDown == 0) {
+        WINGsConfiguration.mouseWheelDown = Button5;
     }
 
 }
