@@ -98,8 +98,8 @@ static Bool caseSensitive = True;
 
 #define CHECK_BUFFER_SIZE(buf, ptr) \
     if ((ptr) >= (buf).size-1) {\
-      (buf).size += BUFFERSIZE_INCREMENT;\
-      (buf).str = wrealloc((buf).str, (buf).size);\
+    (buf).size += BUFFERSIZE_INCREMENT;\
+    (buf).str = wrealloc((buf).str, (buf).size);\
     }
 
 
@@ -132,9 +132,9 @@ hashPropList(WMPropList *plist)
             ctr = (ctr + 1) % sizeof (char *);
         }
         /*while (*key) {
-           ret ^= tolower(*key++) << ctr;
-           ctr = (ctr + 1) % sizeof (char *);
-        }*/
+         ret ^= tolower(*key++) << ctr;
+         ctr = (ctr + 1) % sizeof (char *);
+         }*/
         break;
 
     case WPLData:
@@ -865,7 +865,7 @@ getPropList(PLData *pldata)
         break;
 
     case '(':
-        DPUT("Getting PropList srrsy");
+        DPUT("Getting PropList array");
         plist = getPLArray(pldata);
         break;
 
@@ -1269,7 +1269,7 @@ WMSubtractPLDictionaries(WMPropList *dest, WMPropList *source, Bool recursive)
         if (WMIsPropListEqualTo(value, dvalue)) {
             WMRemoveFromPLDictionary(dest, key);
         } else if (recursive && value->type==WPLDictionary &&
-            dvalue->type==WPLDictionary) {
+                   dvalue->type==WPLDictionary) {
             WMSubtractPLDictionaries(dvalue, value, True);
         }
     }
@@ -1593,7 +1593,7 @@ WMReadPropListFromFile(char *file)
     struct stat stbuf;
     size_t length;
 
-    f = fopen(file, "r");
+    f = fopen(file, "rb");
     if (!f) {
         /* let the user print the error message if he really needs to */
         /*wsyserror(_("could not open domain file '%s' for reading"), file);*/
@@ -1615,7 +1615,9 @@ WMReadPropListFromFile(char *file)
     pldata->lineNumber = 1;
 
     if (fread(pldata->ptr, length, 1, f) != 1) {
-        wsyserror(_("error reading from file '%s'"), file);
+        if (ferror(f)) {
+            wsyserror(_("error reading from file '%s'"), file);
+        }
         plist = NULL;
         goto cleanup;
     }
@@ -1672,7 +1674,7 @@ WMWritePropListToFile(WMPropList *plist, char *path, Bool atomically)
         mask = umask(0);
         umask(mask);
         fchmod(fd, 0644 & ~mask);
-        if ((theFile = fdopen(fd, "w")) == NULL) {
+        if ((theFile = fdopen(fd, "wb")) == NULL) {
             close(fd);
         }
 #else
