@@ -474,7 +474,7 @@ wMaximizeWindow(WWindow *wwin, int directions)
 void
 wUnmaximizeWindow(WWindow *wwin)
 {
-    int restore_x, restore_y;
+    int x, y, w, h;
 
     if (!wwin->flags.maximized)
         return;
@@ -483,13 +483,17 @@ wUnmaximizeWindow(WWindow *wwin)
         wwin->flags.skip_next_animation = 1;
         wUnshadeWindow(wwin);
     }
-    restore_x = (wwin->flags.maximized & MAX_HORIZONTAL) ?
+    x = ((wwin->flags.maximized & MAX_HORIZONTAL) && wwin->old_geometry.x) ?
         wwin->old_geometry.x : wwin->frame_x;
-    restore_y = (wwin->flags.maximized & MAX_VERTICAL) ?
+    y = ((wwin->flags.maximized & MAX_VERTICAL) && wwin->old_geometry.y) ?
         wwin->old_geometry.y : wwin->frame_y;
+    w = wwin->old_geometry.width ?
+        wwin->old_geometry.width : wwin->client.width;
+    h = wwin->old_geometry.height ?
+        wwin->old_geometry.height : wwin->client.height;
+
     wwin->flags.maximized = 0;
-    wWindowConfigure(wwin, restore_x, restore_y,
-                     wwin->old_geometry.width, wwin->old_geometry.height);
+    wWindowConfigure(wwin, x, y, w, h);
 
     WMPostNotificationName(WMNChangedState, wwin, "maximize");
 
@@ -771,6 +775,7 @@ animateResize(WScreen *scr, int x, int y, int w, int h,
     }
 
     k = (hiding ? 2 : 3);
+
     switch(style) {
     case WIS_TWIST:
         steps = (MINIATURIZE_ANIMATION_STEPS_T * k)/3;
@@ -1343,6 +1348,7 @@ wHideApplication(WApplication *wapp)
     WScreen *scr;
     WWindow *wlist;
     int hadfocus;
+    int animate;
 
     if (!wapp) {
         wwarning("trying to hide a non grouped window");
@@ -1362,15 +1368,19 @@ wHideApplication(WApplication *wapp)
         wapp->last_focused = wlist;
     else
         wapp->last_focused = NULL;
+
+    animate = !wapp->flags.skip_next_animation;
+
     while (wlist) {
         if (wlist->main_window == wapp->main_window) {
             if (wlist->flags.focused) {
                 hadfocus = 1;
             }
-            if (wapp->app_icon)
+            if (wapp->app_icon) {
                 hideWindow(wapp->app_icon->icon, wapp->app_icon->x_pos,
-                           wapp->app_icon->y_pos, wlist,
-                           !wapp->flags.skip_next_animation);
+                           wapp->app_icon->y_pos, wlist, animate);
+                animate = False;
+            }
         }
         wlist = wlist->prev;
     }
@@ -1448,7 +1458,7 @@ wUnhideApplication(WApplication *wapp, Bool miniwindows, Bool bringToCurrentWS)
     WScreen *scr;
     WWindow *wlist, *next;
     WWindow *focused=NULL;
-    Bool shouldArrangeIcons = False;
+    int animate;
 
     if (!wapp)
         return;
@@ -1462,6 +1472,8 @@ wUnhideApplication(WApplication *wapp, Bool miniwindows, Bool bringToCurrentWS)
     while (wlist->prev)
         wlist = wlist->prev;
 
+    animate = !wapp->flags.skip_next_animation;
+
     while (wlist) {
         next = wlist->next;
 
@@ -1475,9 +1487,18 @@ wUnhideApplication(WApplication *wapp, Bool miniwindows, Bool bringToCurrentWS)
                 if (bringToCurrentWS || wPreferences.sticky_icons ||
                     wlist->frame->workspace == scr->current_workspace) {
                     if (wlist->icon && !wlist->icon->mapped) {
+                        int x, y;
+
+                        PlaceIcon(scr, &x, &y, wGetHeadForWindow(wlist));
+                        if (wlist->icon_x!=x || wlist->icon_y!=y) {
+                            XMoveWindow(dpy, wlist->icon->core->window, x, y);
+                        }
+                        wlist->icon_x = x;
+                        wlist->icon_y = y;
                         XMapWindow(dpy, wlist->icon->core->window);
                         wlist->icon->mapped = 1;
                     }
+                    wRaiseFrame(wlist->icon->core);
                 }
                 if (bringToCurrentWS)
                     wWindowChangeWorkspace(wlist, scr->current_workspace);
@@ -1486,7 +1507,6 @@ wUnhideApplication(WApplication *wapp, Bool miniwindows, Bool bringToCurrentWS)
                     wlist->frame->workspace == scr->current_workspace) {
                     wDeiconifyWindow(wlist);
                 }
-                shouldArrangeIcons = True;
                 WMPostNotificationName(WMNChangedState, wlist, "hide");
             } else if (wlist->flags.shaded) {
                 if (bringToCurrentWS)
@@ -1502,9 +1522,9 @@ wUnhideApplication(WApplication *wapp, Bool miniwindows, Bool bringToCurrentWS)
                 WMPostNotificationName(WMNChangedState, wlist, "hide");
             } else if (wlist->flags.hidden) {
                 unhideWindow(wapp->app_icon->icon, wapp->app_icon->x_pos,
-                             wapp->app_icon->y_pos, wlist,
-                             !wapp->flags.skip_next_animation,
+                             wapp->app_icon->y_pos, wlist, animate,
                              bringToCurrentWS);
+                animate = False;
             } else {
                 if (bringToCurrentWS
                     && wlist->frame->workspace != scr->current_workspace) {
@@ -1526,7 +1546,7 @@ wUnhideApplication(WApplication *wapp, Bool miniwindows, Bool bringToCurrentWS)
         wSetFocusTo(scr, focused);
     }
     wapp->last_focused = NULL;
-    if (shouldArrangeIcons || wPreferences.auto_arrange_icons) {
+    if (wPreferences.auto_arrange_icons) {
         wArrangeIcons(scr, True);
     }
 #ifdef HIDDENDOT
@@ -1535,7 +1555,6 @@ wUnhideApplication(WApplication *wapp, Bool miniwindows, Bool bringToCurrentWS)
 }
 
 
-
 void
 wShowAllWindows(WScreen *scr)
 {
