@@ -50,12 +50,15 @@ static void raiseWindow(WSwitchPanel *swpanel, WWindow *wwin)
     Window swwin= wSwitchPanelGetWindow(swpanel);
     
     if (wwin->flags.mapped) {
-        Window win[2];
+        if (swwin!=None) {
+            Window win[2];
     
-        win[0]= swwin;
-        win[1]= wwin->frame->core->window;
+            win[0]= swwin;
+            win[1]= wwin->frame->core->window;
     
-        XRestackWindows(dpy, win, 2);
+            XRestackWindows(dpy, win, 2);
+        } else
+            XRaiseWindow(dpy, wwin->frame->core->window);
     }
 }
 
@@ -204,7 +207,8 @@ StartWindozeCycle(WWindow *wwin, XEvent *event, Bool next)
                 }
             }
             break;
-            
+         
+        case LeaveNotify:
         case MotionNotify:
         case ButtonRelease:
             {
@@ -243,6 +247,9 @@ StartWindozeCycle(WWindow *wwin, XEvent *event, Bool next)
         XUngrabKeyboard(dpy, CurrentTime);
     }
 
+    if (swpanel)
+        wSwitchPanelDestroy(swpanel);
+
     if (newFocused) {
         wRaiseFrame(newFocused->frame->core);
         CommitStacking(scr);
@@ -251,11 +258,6 @@ StartWindozeCycle(WWindow *wwin, XEvent *event, Bool next)
         wSetFocusTo(scr, newFocused);
     }
 
-    if (!getenv("SWPDEBUG"))
-    {
-        if (swpanel)
-          wSwitchPanelDestroy(swpanel);
-    }
     scr->flags.doing_alt_tab = 0;
 
     if (somethingElse)
