@@ -1,8 +1,8 @@
 /*
  *  Window Maker window manager
- * 
- *  Copyright (c) 1997-2002 Alfredo K. Kojima
- * 
+ *
+ *  Copyright (c) 1997-2003 Alfredo K. Kojima
+ *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
@@ -15,7 +15,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, 
+ *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  */
 
@@ -28,10 +28,6 @@
 
 #include <WINGs/WUtil.h>
 
-#ifdef XINERAMA
-#include <X11/extensions/Xinerama.h>
-#endif
-
 
 #define WTB_LEFT	0
 #define WTB_RIGHT	1
@@ -42,6 +38,15 @@
 #define WTB_MENU 6
 
 
+
+typedef struct {
+    WMRect *screens;
+    int count;                 /* screen count, 0 = inactive */
+    int primary_head;	       /* main working screen */
+} WXineramaInfo;
+
+
+
 /* an area of the screen reserved by some window */
 typedef struct WReservedArea {
     WArea area;
@@ -72,10 +77,8 @@ typedef struct _WScreen {
     int scr_height;
 
 #ifdef VIRTUAL_DESKTOP
-    Window virtual_edge_u;
-    Window virtual_edge_d;
-    Window virtual_edge_l;
-    Window virtual_edge_r;
+    int virtual_nr_edges;
+    Window * virtual_edges;
 #endif
 
     Window root_win;		       /* root window of screen */
@@ -83,29 +86,25 @@ typedef struct _WScreen {
     Colormap colormap;		       /* root colormap */
     int root_colormap_install_count;
     struct WWindow *original_cmap_window; /* colormap before installing
-					* root colormap temporarily */
+                                           * root colormap temporarily */
     struct WWindow *cmap_window;
     Colormap current_colormap;
 
     Window w_win;		       /* window to use as drawable
-					* for new GCs, pixmaps etc. */
+                                        * for new GCs, pixmaps etc. */
     Visual *w_visual;
     int  w_depth;
     Colormap w_colormap;	       /* our colormap */
-    
-#ifdef XINERAMA
-    XineramaScreenInfo *xine_screens;
-    int xine_count;		       /* 0 means not active */
-    int xine_primary_head;	       /* main working screen */
-#endif
+
+    WXineramaInfo xine_info;
 
     Window no_focus_win;	       /* window to get focus when nobody
-					* else can do it */
+                                        * else can do it */
 
     struct WWindow *focused_window;    /* window that has the focus
-					* Use this list if you want to
-					* traverse the entire window list
-					*/
+                                        * Use this list if you want to
+                                        * traverse the entire window list
+                                        */
 
     WMArray *selected_windows;
 
@@ -116,12 +115,12 @@ typedef struct _WScreen {
     struct WApplication *wapp_list;    /* list of all aplications */
 
     WMBag *stacking_list;	       /* bag of lists of windows
-					* in stacking order.
-					* Indexed by window level
-					* and each list on the array
-					* is ordered from the topmost to
-					* the lowest window
-					*/
+                                        * in stacking order.
+                                        * Indexed by window level
+                                        * and each list on the array
+                                        * is ordered from the topmost to
+                                        * the lowest window
+                                        */
 
     int window_count;		       /* number of windows in window_list */
 
@@ -134,39 +133,49 @@ typedef struct _WScreen {
 
     WReservedArea *reservedAreas;      /* used to build totalUsableArea */
 
-    WArea usableArea;		       /* area of the workspace where
-					* we can put windows on, as defined
-					* by other clients (not us) */
-    WArea totalUsableArea;	       /* same as above, but including
-					* the dock and other stuff */
-    
+    WArea *usableArea;		       /* area of the workspace where
+                                        * we can put windows on, as defined
+                                        * by other clients (not us) */
+    WArea *totalUsableArea;	       /* same as above, but including
+                                        * the dock and other stuff */
 
+    WMColor *black;
+    WMColor *white;
+    WMColor *gray;
+    WMColor *darkGray;
+
+    /* shortcuts for the pixels of the above colors. just for convenience */
     WMPixel black_pixel;
     WMPixel white_pixel;
-    
     WMPixel light_pixel;
     WMPixel dark_pixel;
 
     Pixmap stipple_bitmap;
     Pixmap transp_stipple;	       /* for making holes in icon masks for
-					* transparent icon simulation */
+                                        * transparent icon simulation */
     WMFont *title_font;		       /* default font for the titlebars */
     WMFont *menu_title_font;	       /* font for menu titlebars */
     WMFont *menu_entry_font;	       /* font for menu items */
     WMFont *icon_title_font;	       /* for icon titles */
     WMFont *clip_title_font;	       /* for clip titles */
     WMFont *info_text_font;	       /* text on things like geometry
-					* hint boxes */
+                                        * hint boxes */
+
+    XFontStruct *tech_draw_font;       /* font for tech draw style geom view
+                                          needs to be a core font so we can
+                                          use it with a XORing GC */
+
     WMFont *workspace_name_font;
 
-    WMPixel select_pixel;
-    WMPixel select_text_pixel;
+    WMColor *select_color;
+    WMColor *select_text_color;
     /* foreground colors */
-    WMPixel window_title_pixel[3];     /* window titlebar text (foc, unfoc, pfoc)*/
-    WMPixel menu_title_pixel[3];       /* menu titlebar text */
-    WMPixel clip_title_pixel[2];       /* clip title text */
-    WMPixel mtext_pixel;	        /* menu item text */
-    WMPixel dtext_pixel;	        /* disabled menu item text */
+    WMColor *window_title_color[3];    /* window titlebar text (foc, unfoc, pfoc)*/
+    WMColor *menu_title_color[3];      /* menu titlebar text */
+    WMColor *clip_title_color[2];      /* clip title text */
+    WMColor *mtext_color;	       /* menu item text */
+    WMColor *dtext_color;	       /* disabled menu item text */
+
     WMPixel line_pixel;
     WMPixel frame_border_pixel;	       /* frame border */
 
@@ -178,22 +187,16 @@ typedef struct _WScreen {
     union WTexture *menu_item_texture; /* menu item texture */
 
     struct WTexSolid *menu_item_auxtexture; /* additional texture to draw menu
-					* cascade arrows */
+    * cascade arrows */
     struct WTexSolid *icon_title_texture;/* icon titles */
-    
+
     struct WTexSolid *widget_texture;
 
     struct WTexSolid *icon_back_texture; /* icon back color for shadowing */
 
-    GC window_title_gc;		       /* window title text GC */
-    GC menu_title_gc;		       /* menu titles */
-    
-    GC icon_title_gc;		       /* icon title background */
-    GC clip_title_gc;		       /* clip title */
-    GC menu_entry_gc;		       /* menu entries */
-    GC select_menu_gc;		       /* selected menu entries */
-    GC disabled_menu_entry_gc;	       /* disabled menu entries */
-    GC info_text_gc;		       /* for size/position display */
+
+    WMColor *icon_title_color;	       /* icon title color */
+
     GC icon_select_gc;
 
     GC frame_gc;		       /* gc for resize/move frame (root) */
@@ -233,9 +236,9 @@ typedef struct _WScreen {
     struct WDock *last_dock;
     WAppIconChain *global_icons;       /* for omnipresent icons chain in clip */
     int global_icon_count;	       /* How many global icons do we have */
-    
+
     Window clip_balloon;	       /* window for workspace name */
-    
+
     int keymove_tick;
 
 #ifdef GRADIENT_CLIP_ARROW
@@ -243,9 +246,9 @@ typedef struct _WScreen {
 #endif
 
     struct RContext *rcontext;	       /* wrlib context */
-    
+
     WMScreen *wmscreen;		       /* for widget library */
-    
+
     struct RImage *icon_tile;
     struct RImage *clip_tile;
     Pixmap icon_tile_pixmap;	       /* for app supplied icons */
@@ -254,8 +257,8 @@ typedef struct _WScreen {
     Pixmap def_ticon_pixmap;
 
     struct WDialogData *dialog_data;
-    
-    
+
+
     struct W_GeometryView *gview;      /* size/position view */
 
 #ifdef NEWSTUFF
@@ -271,7 +274,7 @@ typedef struct _WScreen {
     Time last_click_time;
     Window last_click_window;
     int last_click_button;
-    
+
     /* balloon help data */
     struct _WBalloon *balloon;
 
@@ -283,11 +286,7 @@ typedef struct _WScreen {
     /* for raise-delay */
     WMHandlerID *autoRaiseTimer;
     Window autoRaiseWindow;	       /* window that is scheduled to be
-					* raised */
-
-
-    Window scrolledFMaximize;	       /* full maximized window which was
-					scrolled down for titlebar access */
+                                        * raised */
 
     /* for window shortcuts */
     WMArray *shortcutWindows[MAX_WINDOW_SHORTCUTS];
@@ -296,11 +295,7 @@ typedef struct _WScreen {
     char *xdestring;
 #endif
 
-#ifdef KWM_HINTS
-    Window kwm_dock;
-#endif
-    
-#ifdef NET_HINTS
+#ifdef NETWM_HINTS
     struct NetData *netdata;
 #endif
 
@@ -308,45 +303,34 @@ typedef struct _WScreen {
     pid_t helper_pid;
 
     struct {
-	unsigned int startup:1;	       /* during window manager startup */
-	unsigned int regenerate_icon_textures:1;
-	unsigned int dnd_data_convertion_status:1;
-	unsigned int root_menu_changed_shortcuts:1;
-	unsigned int added_workspace_menu:1;
-	unsigned int added_windows_menu:1;
-	unsigned int startup2:1;       /* startup phase 2 */
-	unsigned int supports_tiff:1;
-	unsigned int clip_balloon_mapped:1;
-	unsigned int next_click_is_not_double:1;
-	unsigned int backimage_helper_launched:1;
-	/* some client has issued a WM_COLORMAP_NOTIFY */
-	unsigned int colormap_stuff_blocked:1;
-	unsigned int doing_alt_tab:1;
-	unsigned int jump_back_pending:1;
-#ifdef KWM_HINTS
-	unsigned int kwm_syncing_name:1;
-	unsigned int kwm_syncing_count:1;
-#endif
+        unsigned int startup:1;	       /* during window manager startup */
+        unsigned int regenerate_icon_textures:1;
+        unsigned int dnd_data_convertion_status:1;
+        unsigned int root_menu_changed_shortcuts:1;
+        unsigned int added_workspace_menu:1;
+        unsigned int added_windows_menu:1;
+        unsigned int startup2:1;       /* startup phase 2 */
+        unsigned int supports_tiff:1;
+        unsigned int clip_balloon_mapped:1;
+        unsigned int next_click_is_not_double:1;
+        unsigned int backimage_helper_launched:1;
+        /* some client has issued a WM_COLORMAP_NOTIFY */
+        unsigned int colormap_stuff_blocked:1;
+        unsigned int doing_alt_tab:1;
+        unsigned int jump_back_pending:1;
+        unsigned int ignore_focus_events:1;
     } flags;
 } WScreen;
 
 
-#define WSS_ROOTMENU	(1<<0)
-#define WSS_SWITCHMENU	(1<<1)
-#define WSS_WSMENU	(1<<2)
-
-/* changes must update wSaveScreenState/getWorkspaceState */
-typedef struct WWorkspaceState {
-    int flags;
-    int workspace;
-} WWorkspaceState;
-
 
 WScreen *wScreenInit(int screen_number);
 void wScreenSaveState(WScreen *scr);
 void wScreenRestoreState(WScreen *scr);
 
 int wScreenBringInside(WScreen *scr, int *x, int *y, int width, int height);
+int wScreenKeepInside(WScreen *scr, int *x, int *y, int width, int height);
+
 
 /* in startup.c */
 WScreen *wScreenWithNumber(int i);
