@@ -25,12 +25,6 @@
 #include <string.h>
 #include <sys/time.h>
 
-#ifdef SHAPE
-#include <X11/extensions/shape.h>
-
-extern Bool wShapeSupported;
-#endif
-
 #include "WindowMaker.h"
 #include "screen.h"
 #include "wcore.h"
@@ -41,6 +35,13 @@ extern Bool wShapeSupported;
 #include "funcs.h"
 #include "xinerama.h"
 
+#ifdef SHAPE
+#include <X11/extensions/shape.h>
+
+extern Bool wShapeSupported;
+#endif
+
+
 struct SwitchPanel {
     WScreen *scr;
     WMWindow *win;
@@ -95,10 +96,10 @@ static int canReceiveFocus(WWindow *wwin)
 }
 
 
-static void changeImage(WSwitchPanel *panel, int index, int selected)
+static void changeImage(WSwitchPanel *panel, int idecks, int selected)
 {
-    WMFrame *icon = WMGetFromArray(panel->icons, index);
-    RImage *image= WMGetFromArray(panel->images, index);
+    WMFrame *icon = WMGetFromArray(panel->icons, idecks);
+    RImage *image= WMGetFromArray(panel->images, idecks);
 
     if (!panel->bg && !panel->tile) {
         if (!selected)
@@ -112,7 +113,7 @@ static void changeImage(WSwitchPanel *panel, int index, int selected)
         WMPoint pos;
         Pixmap p;
 
-        if (canReceiveFocus(WMGetFromArray(panel->windows, index)) < 0)
+        if (canReceiveFocus(WMGetFromArray(panel->windows, idecks)) < 0)
           opaq= 50;
 
         pos= WMGetViewPosition(WMWidgetView(icon));
@@ -354,43 +355,51 @@ static RImage *getTile(WSwitchPanel *panel)
 
 
 static void
-drawTitle(WSwitchPanel *panel, int index, char *title)
+drawTitle(WSwitchPanel *panel, int idecks, char *title)
 {
     char *ntitle;
     int width= WMWidgetWidth(panel->win);
     int x;
 
-    ntitle= ShrinkString(panel->font, title, width-2*BORDER_SPACE);
+    if (title)
+        ntitle= ShrinkString(panel->font, title, width-2*BORDER_SPACE);
+    else
+        ntitle= NULL;
 
     if (panel->bg) {
-        if (strcmp(ntitle, title)!=0)
-          x= BORDER_SPACE;
-        else
-        {
-            int w= WMWidthOfString(panel->font, ntitle, strlen(ntitle));
-            
-            x= BORDER_SPACE+(index-panel->firstVisible)*ICON_TILE_SIZE + ICON_TILE_SIZE/2 - w/2;
-            if (x < BORDER_SPACE)
+        if (ntitle) {
+            if (strcmp(ntitle, title)!=0)
               x= BORDER_SPACE;
-            else if (x + w > width-BORDER_SPACE)
-              x= width-BORDER_SPACE-w;
-        }
-        
+            else
+            {
+                int w= WMWidthOfString(panel->font, ntitle, strlen(ntitle));
+            
+                x= BORDER_SPACE+(idecks-panel->firstVisible)*ICON_TILE_SIZE + ICON_TILE_SIZE/2 - w/2;
+                if (x < BORDER_SPACE)
+                    x= BORDER_SPACE;
+                else if (x + w > width-BORDER_SPACE)
+                    x= width-BORDER_SPACE-w;
+            }
+        }       
         XClearWindow(dpy, WMWidgetXID(panel->win));
-        WMDrawString(panel->scr->wmscreen, 
-                     WMWidgetXID(panel->win),
-                     panel->white, panel->font,
-                     x, WMWidgetHeight(panel->win) - BORDER_SPACE - LABEL_HEIGHT + WMFontHeight(panel->font)/2,
-                     ntitle, strlen(ntitle));
+        if (ntitle)
+            WMDrawString(panel->scr->wmscreen, 
+                         WMWidgetXID(panel->win),
+                         panel->white, panel->font,
+                         x, WMWidgetHeight(panel->win) - BORDER_SPACE - LABEL_HEIGHT + WMFontHeight(panel->font)/2,
+                         ntitle, strlen(ntitle));
     } else {
-        WMSetLabelText(panel->label, ntitle);
+        if (ntitle)
+            WMSetLabelText(panel->label, ntitle);
     }
-    free(ntitle);
+    if (ntitle)
+        free(ntitle);
 }
 
 
 
-static WMArray *makeWindowListArray(WScreen *scr, WWindow *curwin, int workspace)
+static WMArray *makeWindowListArray(WScreen *scr, WWindow *curwin, int workspace,
+                                    int include_unmapped)
 {
     WMArray *windows= WMCreateArray(10);
     int fl;
@@ -399,7 +408,8 @@ static WMArray *makeWindowListArray(WScreen *scr, WWindow *curwin, int workspace
     for (fl= 0; fl < 2; fl++) {
         for (wwin= curwin; wwin; wwin= wwin->prev) {
             if (((!fl && canReceiveFocus(wwin) > 0) || (fl && canReceiveFocus(wwin) < 0)) &&
-                (!WFLAGP(wwin, skip_window_list) || wwin->flags.internal_window)) {
+                (!WFLAGP(wwin, skip_window_list) || wwin->flags.internal_window) &&
+                (wwin->flags.mapped || include_unmapped)) {
                 WMAddToArray(windows, wwin);
             }
         }
@@ -410,7 +420,8 @@ static WMArray *makeWindowListArray(WScreen *scr, WWindow *curwin, int workspace
         
         for (wwin= curwin; wwin && wwin != curwin; wwin= wwin->prev) {
             if (((!fl && canReceiveFocus(wwin) > 0) || (fl && canReceiveFocus(wwin) < 0)) &&
-                (!WFLAGP(wwin, skip_window_list) || wwin->flags.internal_window)) {
+                (!WFLAGP(wwin, skip_window_list) || wwin->flags.internal_window) &&
+                (wwin->flags.mapped || include_unmapped)) {
                 WMAddToArray(windows, wwin);
             }
         }
@@ -439,7 +450,8 @@ WSwitchPanel *wInitSwitchPanel(WScreen *scr, WWindow *curwin, int workspace)
 
     panel->scr= scr;
 
-    panel->windows= makeWindowListArray(scr, curwin, workspace);
+    panel->windows= makeWindowListArray(scr, curwin, workspace,
+                                        wPreferences.swtileImage!=0);
     count= WMGetArrayItemCount(panel->windows);
     
     if (count == 0) {
@@ -458,6 +470,9 @@ WSwitchPanel *wInitSwitchPanel(WScreen *scr, WWindow *curwin, int workspace)
     
     panel->visibleCount= iconsThatFitCount;
 
+    if (!wPreferences.swtileImage)
+        return panel;
+
     height= LABEL_HEIGHT + ICON_TILE_SIZE;
 
     panel->tileTmp= RCreateImage(ICON_TILE_SIZE, ICON_TILE_SIZE, 1);
@@ -672,12 +687,15 @@ WWindow *wSwitchPanelHandleEvent(WSwitchPanel *panel, XEvent *event)
 {
     WMFrame *icon;
     int i;
+    int focus= -1;
     
     if (!panel->win)
       return NULL;
 
-    if (event->type == MotionNotify) {
-        int focus= -1;
+ /*   if (event->type == LeaveNotify) {
+        if (event->xcrossing.window == WMWidgetXID(panel->win))
+            focus= 0;
+    } else*/ if (event->type == MotionNotify) {
 
         WM_ITERATE_ARRAY(panel->icons, icon, i) {
             if (WMWidgetXID(icon) == event->xmotion.window) {
@@ -685,23 +703,19 @@ WWindow *wSwitchPanelHandleEvent(WSwitchPanel *panel, XEvent *event)
                 break;
             }
         }
-
-        if (focus < 0)
-          focus= 0;
-        
-        if (focus >= 0 && panel->current != focus) {
-            WWindow *wwin;
+    }  
+    if (focus >= 0 && panel->current != focus) {
+        WWindow *wwin;
             
-            changeImage(panel, panel->current, 0);
-            changeImage(panel, focus, 1);
-            panel->current= focus;
+        changeImage(panel, panel->current, 0);
+        changeImage(panel, focus, 1);
+        panel->current= focus;
             
-            wwin= WMGetFromArray(panel->windows, focus);
+        wwin= WMGetFromArray(panel->windows, focus);
             
-            drawTitle(panel, panel->current, wwin->frame->title);
+        drawTitle(panel, panel->current, wwin->frame->title);
             
-            return wwin;
-        }
+        return wwin;
     }
 
     return NULL;
